@@ -1,11 +1,13 @@
-import paco.models.applications
-import paco.models.networks
-import paco.models.resources
 from paco.models import schemas
 from paco.models.base import Named
 from paco.models.schemas import IProject, IVersionControl, IPacoWorkBucket, ISharedState
 from zope.interface import implementer
 from zope.schema.fieldproperty import FieldProperty
+import paco.models.applications
+import paco.models.networks
+import paco.models.resources
+import paco.models.metrics
+import paco.models.logging
 
 
 @implementer(IVersionControl)
@@ -37,6 +39,7 @@ class SharedState(Named):
         self.paco_work_bucket = PacoWorkBucket('paco_work_bucket', self)
 
     paco_work_bucket = FieldProperty(schemas.ISharedState["paco_work_bucket"])
+    cloudformation_region = FieldProperty(schemas.ISharedState["cloudformation_region"])
 
 @implementer(IProject)
 class Project(Named, dict):
@@ -48,6 +51,7 @@ class Project(Named, dict):
     def __init__(self, name, __parent__):
         super().__init__(name, __parent__)
         self.legacy_flags = []
+        self.resource_registry = {}
 
         # Version Control
         self.version_control = VersionControl('version_control', self)
@@ -91,6 +95,26 @@ class Project(Named, dict):
         self.resource['ssm'] = paco.models.resources.SSMResource('ssm', self.resource)
         self.resource['ssm'].title = 'SSM Resource'
 
+        # Monitoring
+        self.monitor = paco.models.metrics.Monitor('monitor', self)
+
+        # Alarm Sets
+        self.monitor.alarm_sets = paco.models.metrics.AlarmSets('alarm_sets', self.monitor)
+
+        # CloudWatch Logging
+        self.monitor.cw_logging = paco.models.logging.CloudWatchLogging('cw_logging', self.resource)
+
+    def get_all_resources_by_type(self, resource_type):
+        """
+        Every resource of a given type across ALL Applications.
+        Should include NetEnv Apps and Service Apps or any Resource loaded in an Application
+        """
+        if resource_type not in self.resource_registry:
+            return []
+        return [
+            resource for resource in self.resource_registry[resource_type].values()
+        ]
+
     def find_object_from_cli(self, controller_type, component_name=None, config_name=None):
         found = None
         CONTROLLER_MAPPING = {
